@@ -1,5 +1,5 @@
 from typing import List
-from codeball import GameDataset, Zone
+from codeball import GameDataset, Zones
 from codeball.patterns import PatternEvent, Pattern
 
 
@@ -21,7 +21,7 @@ class PassesIntoTheBox(Pattern):
 
         passes_into_the_box = (
             self.game_dataset.events.type("PASS")
-            .into(Zone.OPPONENT_BOX)
+            .into(Zones.OPPONENT_BOX)
             .result("COMPLETE")
         )
 
